==> paraview_5.4.1+dfsg4.orig.tar.xz: paraview-5.4.1+dfsg4/VTK/IO/Legacy/vtkSimplePointsWriter.h <==
/*=========================================================================

  Program:   Visualization Toolkit
  Module:    vtkSimplePointsWriter.h

  Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
  All rights reserved.
  See Copyright.txt or http://www.kitware.com/Copyright.htm for details.

     This software is distributed WITHOUT ANY WARRANTY; without even
     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
     PURPOSE.  See the above copyright notice for more information.

=========================================================================*/
/**
 * @class   vtkSimplePointsWriter
 * @brief   write a file of xyz coordinates
 *
 * vtkSimplePointsWriter writes a simple file of xyz coordinates
 *
 * @sa
 * vtkSimplePointsReader
*/

#ifndef vtkSimplePointsWriter_h
#define vtkSimplePointsWriter_h

#include "vtkIOLegacyModule.h" // For export macro
#include "vtkDataSetWriter.h"

class VTKIOLEGACY_EXPORT vtkSimplePointsWriter : public vtkDataSetWriter
{
public:
  static vtkSimplePointsWriter *New();
  vtkTypeMacro(vtkSimplePointsWriter,vtkDataSetWriter);
  void PrintSelf(ostream& os, vtkIndent indent) VTK_OVERRIDE;

  vtkGetMacro(DecimalPrecision, int);
  vtkSetMacro(DecimalPrecision, int);

protected:
  vtkSimplePointsWriter();
  ~vtkSimplePointsWriter() VTK_OVERRIDE{}

  void WriteData() VTK_OVERRIDE;

  int DecimalPrecision;

private:
  vtkSimplePointsWriter(const vtkSimplePointsWriter&) VTK_DELETE_FUNCTION;
  void operator=(const vtkSimplePointsWriter&) VTK_DELETE_FUNCTION;
};

#endif

==> paraview_5.11.0+dfsg.orig.tar.xz: paraview-5.11.0+dfsg/VTK/IO/Legacy/vtkSimplePointsWriter.h <==
/*=========================================================================

  Program:   Visualization Toolkit
  Module:    vtkSimplePointsWriter.h

  Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
  All rights reserved.
  See Copyright.txt or http://www.kitware.com/Copyright.htm for details.

     This software is distributed WITHOUT ANY WARRANTY; without even
     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
     PURPOSE.  See the above copyright notice for more information.

=========================================================================*/
/**
 * @class   vtkSimplePointsWriter
 * @brief   write a file of xyz coordinates
 *
 * vtkSimplePointsWriter writes a simple file of xyz coordinates
 *
 * @sa
 * vtkSimplePointsReader
 */

#ifndef vtkSimplePointsWriter_h
#define vtkSimplePointsWriter_h

#include "vtkDataSetWriter.h"
#include "vtkIOLegacyModule.h" // For export macro

VTK_ABI_NAMESPACE_BEGIN
class VTKIOLEGACY_EXPORT vtkSimplePointsWriter : public vtkDataSetWriter
{
public:
  static vtkSimplePointsWriter* New();
  vtkTypeMacro(vtkSimplePointsWriter, vtkDataSetWriter);
  void PrintSelf(ostream& os, vtkIndent indent) override;

  vtkGetMacro(DecimalPrecision, int);
  vtkSetMacro(DecimalPrecision, int);

protected:
  vtkSimplePointsWriter();
  ~vtkSimplePointsWriter() override = default;

  void WriteData() override;

  int DecimalPrecision;

private:
  vtkSimplePointsWriter(const vtkSimplePointsWriter&) = delete;
  void operator=(const vtkSimplePointsWriter&) = delete;
};

VTK_ABI_NAMESPACE_END
#endif
